capture log close
log using vf99noaw.log, replace                       
clear
set memory 1000m
set matsize 6600


**********************************************************************************************
*				RE-DO WITHOUT ENSEMBLE SIZE WEIGHTS
**********************************************************************************************




**********************************************************************************************
*				LT ANALYSES
**********************************************************************************************

use "lt.dta"
generate t=_n

sum

**************************************************************************************************************************
*
*                     COMPARE TRENDS USING MULTIVARIATE METHOD OF VOGELSANG&FRANSES 2005
*				USE BALANCED PANEL (UP TO 1999)
*
**************************************************************************************************************************

drop if year>1999

*	Get OLS beta and residual matrices
forvalues j=1/23 {
	regress mlt`j' t 
	predict r`j' , resid 
	matrix c=e(b)'
	matrix b`j'=c["t","y1"]
	matrix list b`j'
	}

regress ltuah t 
	predict r24 , resid 
	matrix c=e(b)'
	matrix b24=c["t","y1"]

regress ltrss t 
	predict r25 , resid
	matrix c=e(b)'
	matrix b25=c["t","y1"]

regress lthad t
	predict r26 , resid
	matrix c=e(b)'
	matrix b26=c["t","y1"]

regress ltrich t	
	predict r27 , resid
	matrix c=e(b)'
	matrix b27=c["t","y1"]

matrix b=[b1,b2,b3,b4,b5,b6,b7,b8,b9,b10,b11,b12,b13,b14,b15,b16,b17,b18,b19,b20,b21,b22,b23,b24,b25,b26,b27]'
matrix list b
sum

mkmat r1-r27, matrix(ut)
matrix dir
matrix u=ut'				// transpose residual matrix into 27x252


*			Make u vectors

forvalues j=1/252 {			// extract u1 - u252 vectors
	matrix u`j'=u[1..27,`j']
	}


*			Make S-hat matrices
matrix ss1=u1*u1'

forvalues j=2/252 {
	matrix cumu=u1-u1			// set cumu to zero vector

	forvalues i=1/`j' {
		matrix cumu=cumu+u`i'	// sum u1+ --- +uj
				}

	matrix ss`j'=cumu*cumu'
			}

*			Make Omega matrix
matrix omega=I(27)-I(27)			// start at zero

forvalues j=1/252 {
	matrix omega=omega+ss`j'
			}
	matrix omega=2*omega/(252*252)

matrix list omega

*				Make t-mean(t) and call ttilde, then take dot product
egen tmean=mean(t)
generate ttilde=t-tmean
sum ttilde

mkmat ttilde
matrix tterm=ttilde'*ttilde
matrix list tterm

sum


********************************************************************************************************************
*			
*			MAKE t AND F TESTS FOLLOWING t2* and F2* IN VOGELSANG AND FRANSES 2005
*			
********************************************************************************************************************

*	critical values: 95% one-sided t is 5.222; F is 41.53

forvalues j=1/27 {

	matrix R=I(27)-I(27)			// start by making R as a 27x27 matrix of zeros, then put 1 in (j,j) slot
	matrix R[`j',`j']=1			// will test slope of model 1 for reference. 

	matrix rt=R[`j',1..27]
	matrix tbot=cholesky((rt*omega*rt')*inv(tterm))

	matrix rb=rt*b

	matrix t`j'=rb*inv(tbot)

	matrix fbot=syminv(R*omega*R')

	matrix F`j'=tterm*(R*b)'*fbot*(R*b)
	display "t"`j' " = " t`j'[1,1] "    F"`j' " = " F`j'[1,1]

			}



*			Test Average Model Slope = Average Obs Slope
matrix R=I(26)-I(26)			// start by making R as a 26x26 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate weights to test if ensemble means=obs means
*matrix R1=(1,5,1,1,1,1,1,1,2,6,5,3,1,1,1,1,3,5,4,7,4,1,1)
matrix R1=(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
matrix R1=(1/23)*R1
matrix R1R=(-0.25,-0.25,-0.25,-0.25)
matrix R1=R1,R1R				// R1 is now 1x27 vector of testing weights
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F



*			Test UAH Slope = RSS Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,-1,0,0)	
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test MSU Slope = balloon Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.5,.5,-.5,-.5)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test Joint Obs Slope Significance

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.25,.25,.25,.25)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F



**********************************************************************************************
*				MT ANALYSES
**********************************************************************************************
clear
use "mt.dta"
generate t=_n

sum

**************************************************************************************************************************
*
*                     COMPARE TRENDS USING MULTIVARIATE METHOD OF VOGELSANG&FRANSES 2005
*				USE BALANCED PANEL (UP TO 1999)
*
**************************************************************************************************************************

drop if year>1999

*	Get OLS beta and residual matrices
forvalues j=1/23 {
	regress mmt`j' t 
	predict r`j' , resid 
	matrix c=e(b)'
	matrix b`j'=c["t","y1"]
	matrix list b`j'
	}

regress mtuah t 
	predict r24 , resid 
	matrix c=e(b)'
	matrix b24=c["t","y1"]

regress mtrss t 
	predict r25 , resid
	matrix c=e(b)'
	matrix b25=c["t","y1"]

regress mthad t
	predict r26 , resid
	matrix c=e(b)'
	matrix b26=c["t","y1"]

regress mtrich t	
	predict r27 , resid
	matrix c=e(b)'
	matrix b27=c["t","y1"]

matrix b=[b1,b2,b3,b4,b5,b6,b7,b8,b9,b10,b11,b12,b13,b14,b15,b16,b17,b18,b19,b20,b21,b22,b23,b24,b25,b26,b27]'
matrix list b
sum

mkmat r1-r27, matrix(ut)
matrix dir
matrix u=ut'				// transpose residual matrix into 27x252


*			Make u vectors

forvalues j=1/252 {			// extract u1 - u252 vectors
	matrix u`j'=u[1..27,`j']
	}


*			Make S-hat matrices
matrix ss1=u1*u1'

forvalues j=2/252 {
	matrix cumu=u1-u1			// set cumu to zero vector

	forvalues i=1/`j' {
		matrix cumu=cumu+u`i'	// sum u1+ --- +uj
				}

	matrix ss`j'=cumu*cumu'
			}

*			Make Omega matrix
matrix omega=I(27)-I(27)			// start at zero

forvalues j=1/252 {
	matrix omega=omega+ss`j'
			}
	matrix omega=2*omega/(252*252)

matrix list omega

*				Make t-mean(t) and call ttilde, then take dot product
egen tmean=mean(t)
generate ttilde=t-tmean
sum ttilde

mkmat ttilde
matrix tterm=ttilde'*ttilde
matrix list tterm

sum


********************************************************************************************************************
*			
*			MAKE t AND F TESTS FOLLOWING t2* and F2* IN VOGELSANG AND FRANSES 2005
*			
********************************************************************************************************************

*	critical values: 95% one-sided t is 5.222; F is 41.53

forvalues j=1/27 {

	matrix R=I(27)-I(27)			// start by making R as a 27x27 matrix of zeros, then put 1 in (j,j) slot
	matrix R[`j',`j']=1			// will test slope of model 1 for reference. 

	matrix rt=R[`j',1..27]
	matrix tbot=cholesky((rt*omega*rt')*inv(tterm))

	matrix rb=rt*b

	matrix t`j'=rb*inv(tbot)

	matrix fbot=syminv(R*omega*R')

	matrix F`j'=tterm*(R*b)'*fbot*(R*b)
	display "t"`j' " = " t`j'[1,1] "    F"`j' " = " F`j'[1,1]

			}



*			Test Average Model Slope = Average Obs Slope
matrix R=I(26)-I(26)			// start by making R as a 26x26 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate weights to test if ensemble means=obs means
*matrix R1=(1,5,1,1,1,1,1,1,2,6,5,3,1,1,1,1,3,5,4,7,4,1,1)
matrix R1=(1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1)
matrix R1=(1/23)*R1
matrix R1R=(-0.25,-0.25,-0.25,-0.25)
matrix R1=R1,R1R				// R1 is now 1x27 vector of testing weights
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F







*			Test UAH Slope = RSS Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,-1,0,0)	
matrix R=R1\R				// make it top row of R, now R is 27x27

*		Construct F stat
	matrix fbot=syminv(R*omega*R')
	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test MSU Slope = balloon Slope

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.5,.5,-.5,-.5)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


*			Test Joint Obs Slope Significance

matrix R=I(26)-I(26)			// start by making R as a 27x27 matrix of zeros 
matrix R26=J(26,1,0)			// make 26x1-length vector of zeros
matrix R=R,R26				// append it to side of R, making R now 26x27

*			Generate test weights 
matrix R1=(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,.25,.25,.25,.25)	
matrix R=R1\R				// make it top row of R, now R is 27x27

	matrix fbot=syminv(R*omega*R')

	matrix F=tterm*(R*b)'*fbot*(R*b)
	matrix list F


exit

